@@ -1,7 +1,4 @@
 from cirs_063 import CIRS_063
-import constants as C
-from tqdm import tqdm
-import numpy as np
 np.seterr(all='ignore')
     
 
@@ -17,7 +14,4 @@ def main_cirs063_wad(dcm=None, manual_input=None,\
     
     
 if __name__ == '__main__':
-    dcm_path_list = CIRS_063.dcm_list_builder(C.root_path)
-    
-    for idx in tqdm(range(len(dcm_path_list))):
-        dcm = main_cirs063_wad(action_name = 'AnalyseCIRS063')
\ No newline at end of file
+    pass
\ No newline at end of file
